#line 1 "scanner.c"

#line 3 "scanner.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define aalogparse__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer aalogparse__create_buffer
#endif

#ifdef yy_delete_buffer
#define aalogparse__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer aalogparse__delete_buffer
#endif

#ifdef yy_scan_buffer
#define aalogparse__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer aalogparse__scan_buffer
#endif

#ifdef yy_scan_string
#define aalogparse__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string aalogparse__scan_string
#endif

#ifdef yy_scan_bytes
#define aalogparse__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes aalogparse__scan_bytes
#endif

#ifdef yy_init_buffer
#define aalogparse__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer aalogparse__init_buffer
#endif

#ifdef yy_flush_buffer
#define aalogparse__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer aalogparse__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define aalogparse__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state aalogparse__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define aalogparse__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer aalogparse__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define aalogparse_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state aalogparse_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define aalogparse_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state aalogparse_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define aalogparse_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack aalogparse_ensure_buffer_stack
#endif

#ifdef yylex
#define aalogparse_lex_ALREADY_DEFINED
#else
#define yylex aalogparse_lex
#endif

#ifdef yyrestart
#define aalogparse_restart_ALREADY_DEFINED
#else
#define yyrestart aalogparse_restart
#endif

#ifdef yylex_init
#define aalogparse_lex_init_ALREADY_DEFINED
#else
#define yylex_init aalogparse_lex_init
#endif

#ifdef yylex_init_extra
#define aalogparse_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra aalogparse_lex_init_extra
#endif

#ifdef yylex_destroy
#define aalogparse_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy aalogparse_lex_destroy
#endif

#ifdef yyget_debug
#define aalogparse_get_debug_ALREADY_DEFINED
#else
#define yyget_debug aalogparse_get_debug
#endif

#ifdef yyset_debug
#define aalogparse_set_debug_ALREADY_DEFINED
#else
#define yyset_debug aalogparse_set_debug
#endif

#ifdef yyget_extra
#define aalogparse_get_extra_ALREADY_DEFINED
#else
#define yyget_extra aalogparse_get_extra
#endif

#ifdef yyset_extra
#define aalogparse_set_extra_ALREADY_DEFINED
#else
#define yyset_extra aalogparse_set_extra
#endif

#ifdef yyget_in
#define aalogparse_get_in_ALREADY_DEFINED
#else
#define yyget_in aalogparse_get_in
#endif

#ifdef yyset_in
#define aalogparse_set_in_ALREADY_DEFINED
#else
#define yyset_in aalogparse_set_in
#endif

#ifdef yyget_out
#define aalogparse_get_out_ALREADY_DEFINED
#else
#define yyget_out aalogparse_get_out
#endif

#ifdef yyset_out
#define aalogparse_set_out_ALREADY_DEFINED
#else
#define yyset_out aalogparse_set_out
#endif

#ifdef yyget_leng
#define aalogparse_get_leng_ALREADY_DEFINED
#else
#define yyget_leng aalogparse_get_leng
#endif

#ifdef yyget_text
#define aalogparse_get_text_ALREADY_DEFINED
#else
#define yyget_text aalogparse_get_text
#endif

#ifdef yyget_lineno
#define aalogparse_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno aalogparse_get_lineno
#endif

#ifdef yyset_lineno
#define aalogparse_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno aalogparse_set_lineno
#endif

#ifdef yyget_column
#define aalogparse_get_column_ALREADY_DEFINED
#else
#define yyget_column aalogparse_get_column
#endif

#ifdef yyset_column
#define aalogparse_set_column_ALREADY_DEFINED
#else
#define yyset_column aalogparse_set_column
#endif

#ifdef yywrap
#define aalogparse_wrap_ALREADY_DEFINED
#else
#define yywrap aalogparse_wrap
#endif

#ifdef yyget_lval
#define aalogparse_get_lval_ALREADY_DEFINED
#else
#define yyget_lval aalogparse_get_lval
#endif

#ifdef yyset_lval
#define aalogparse_set_lval_ALREADY_DEFINED
#else
#define yyset_lval aalogparse_set_lval
#endif

#ifdef yyalloc
#define aalogparse_alloc_ALREADY_DEFINED
#else
#define yyalloc aalogparse_alloc
#endif

#ifdef yyrealloc
#define aalogparse_realloc_ALREADY_DEFINED
#else
#define yyrealloc aalogparse_realloc
#endif

#ifdef yyfree
#define aalogparse_free_ALREADY_DEFINED
#else
#define yyfree aalogparse_free
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define aalogparse_wrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 146
#define YY_END_OF_BUFFER 147
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[419] =
    {   0,
      144,  144,  147,  131,  146,    1,  131,  146,    1,  146,
       15,  131,  146,   53,  131,  146,   49,  131,  146,   50,
      131,  146,   48,  131,  146,   51,  131,  146,   46,  131,
      146,   47,  131,  146,   45,  131,  146,   52,  131,  146,
      131,  146,  131,  146,  131,  146,  131,  146,  131,  146,
      131,  146,  131,  146,  131,  146,  131,  146,  131,  146,
      131,  146,  131,  146,  131,  146,  131,  146,  131,  146,
      131,  146,  131,  146,  131,  146,  131,  146,  131,  146,
      131,  146,  131,  146,  131,  146,  131,  146,  131,  146,
      131,  146,  131,  146,  131,  146,  146,   18,  146,   16,

      146,  146,   13,  146,   11,  146,   11,   13,  146,   12,
      146,    9,  146,   10,  146,   14,  146,    8,  146,    6,
        8,  146,    7,    8,  146,    5,    8,  146,    2,    8,
      146,    4,    8,  146,  132,  146,  134,  146,  134,  146,
      137,  146,  135,  137,  146,  135,  146,  137,  146,   22,
      146,   19,   22,  146,   22,  146,   21,   22,  146,   44,
      146,   44,  146,   43,   44,  146,   27,   43,   44,  146,
       26,   44,  146,   43,   44,  146,   43,   44,  146,   25,
      146,   25,  146,   24,   25,  146,  143,  146,  138,  143,
      146,  138,  146,  142,  143,  146,  141,  143,  146,  143,

      146,  143,  146,  144,  146,  145,  146,    1,   46,   18,
       17,   13,    2,    3,  132,  134,  134,  135,   20,   43,
       27,   43,   43,   43,   43,   43,  138,  144,   46,  125,
      125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
      125,  109,   95,   57,   73,   91,  106,   88,  134,   43,
       40,   43,   43,   43,   23,  140,   46,  125,  125,   87,
       93,   89,   96,  108,   71,   62,   59,   54,   86,  110,
      115,   68,   56,  134,   43,   43,   43,   23,  124,   46,
      125,   85,  125,  129,  121,  104,   83,  103,  117,  107,
       84,   77,  101,  105,   60,  102,   90,  134,   43,   43,

       43,  139,  125,   65,   80,  116,  112,  113,   99,   69,
      114,  100,  134,   31,   43,   43,   43,  125,   98,  123,
       75,  118,  134,   29,   33,   43,   43,   43,  128,  125,
      125,  125,   55,  120,   92,   74,   82,   79,   94,  134,
       28,   32,   43,   43,   41,   43,  125,   67,  111,   61,
       58,  119,   72,   66,   81,  134,   30,   43,   43,  126,
      128,   97,   78,  134,   43,   43,   43,   43,   43,   42,
       43,16511,   63,   70,  134,   43,   43,   43,   43,   43,
       43,  122,   76,  133,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   37,   43,   43,  128,  130,   64,

      136,   43,   35,   43,   43,   39,   43,   43,   43,   34,
       43,   38,   43,   36,   43, 8319, 8319, 8319
    } ;

static const flex_int16_t yy_accept[707] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    2,    3,    4,    6,    9,   11,   14,
       17,   20,   23,   26,   29,   32,   35,   38,   41,   43,
       45,   47,   49,   51,   53,   55,   57,   59,   61,   63,
       65,   67,   69,   71,   73,   75,   77,   79,   81,   83,
       85,   87,   89,   91,   93,   95,   97,   98,  100,  102,
      103,  105,  107,  110,  112,  114,  116,  118,  120,  123,
      126,  129,  132,  135,  137,  139,  141,  143,  146,  148,
      150,  152,  155,  157,  160,  162,  164,  167,  171,  174,

      177,  180,  182,  184,  187,  189,  192,  194,  197,  200,
      202,  204,  206,  208,  209,  209,  209,  210,  210,  210,
      210,  210,  210,  210,  210,  210,  210,  210,  210,  210,
      210,  210,  210,  210,  210,  210,  210,  210,  210,  210,
      210,  210,  210,  210,  210,  210,  210,  210,  210,  210,
      210,  210,  210,  210,  210,  210,  210,  210,  210,  210,
      210,  210,  210,  210,  210,  210,  210,  210,  210,  210,
      210,  210,  210,  210,  210,  211,  212,  213,  214,  215,
      216,  217,  218,  219,  219,  220,  220,  220,  220,  220,
      220,  221,  223,  224,  225,  226,  227,  227,  228,  228,

      228,  229,  229,  230,  230,  231,  232,  233,  233,  234,
      235,  236,  237,  238,  239,  240,  240,  241,  242,  242,
      242,  242,  242,  242,  242,  243,  243,  243,  243,  243,
      243,  243,  243,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      246,  246,  246,  246,  246,  247,  247,  247,  248,  248,
      248,  248,  248,  248,  249,  250,  250,  250,  250,  250,
      250,  250,  250,  250,  251,  253,  254,  255,  256,  256,
      257,  257,  258,  258,  258,  258,  258,  258,  258,  258,

      259,  260,  260,  260,  261,  261,  261,  261,  262,  262,
      262,  262,  263,  263,  263,  263,  264,  264,  264,  265,
      265,  265,  265,  265,  265,  265,  265,  265,  265,  266,
      266,  266,  266,  266,  266,  266,  267,  267,  267,  268,
      269,  269,  269,  270,  270,  271,  272,  272,  272,  272,
      272,  272,  272,  272,  272,  272,  273,  273,  273,  274,
      275,  275,  275,  275,  275,  275,  275,  275,  276,  277,
      278,  279,  279,  280,  280,  281,  281,  282,  282,  282,
      283,  283,  283,  284,  284,  284,  284,  284,  284,  284,
      285,  285,  285,  286,  287,  287,  288,  288,  289,  289,

      290,  291,  291,  292,  292,  292,  292,  292,  292,  292,
      293,  294,  295,  295,  295,  295,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  297,  298,  298,  298,  298,
      298,  298,  298,  298,  299,  299,  299,  299,  299,  299,
      299,  299,  300,  301,  302,  303,  303,  303,  304,  304,
      304,  304,  304,  304,  304,  304,  304,  304,  304,  304,
      305,  305,  306,  307,  307,  307,  307,  307,  307,  307,
      308,  309,  309,  310,  310,  311,  311,  311,  311,  311,
      311,  311,  311,  312,  312,  312,  313,  313,  313,  313,
      314,  314,  314,  314,  314,  314,  315,  315,  316,  317,

      318,  318,  318,  318,  318,  318,  319,  319,  319,  319,
      319,  319,  319,  320,  320,  320,  320,  320,  320,  320,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  322,
      322,  322,  322,  323,  323,  323,  323,  324,  324,  324,
      324,  325,  325,  326,  326,  327,  328,  329,  329,  330,
      331,  332,  333,  333,  333,  334,  334,  334,  334,  335,
      336,  336,  336,  336,  336,  336,  336,  336,  336,  336,
      337,  337,  338,  338,  338,  339,  340,  340,  341,  341,
      341,  342,  343,  344,  345,  347,  347,  347,  347,  348,
      348,  349,  349,  349,  350,  350,  350,  350,  351,  352,

      353,  354,  354,  354,  355,  356,  356,  357,  357,  358,
      359,  360,  361,  361,  362,  362,  363,  363,  363,  363,
      363,  364,  364,  364,  364,  365,  365,  366,  367,  368,
      369,  370,  372,  373,  373,  373,  374,  374,  374,  375,
      375,  375,  375,  376,  376,  377,  378,  379,  380,  381,
      382,  382,  382,  382,  383,  384,  384,  385,  385,  386,
      387,  388,  389,  390,  391,  391,  391,  391,  391,  391,
      392,  393,  394,  395,  397,  398,  398,  399,  399,  400,
      401,  401,  402,  403,  405,  406,  408,  409,  409,  410,
      412,  414,  414,  416,  416,  416,  417,  417,  417,  417,

      418,  418,  418,  418,  419,  419
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    4,    1,
        1,    5,    6,    7,    1,    1,    1,    1,    8,    9,
       10,    1,   11,    1,   12,   13,    1,   14,   14,   15,
       14,   14,   14,   14,   14,   14,   14,   16,    1,    1,
       17,    1,   18,    1,   19,   20,   21,   22,   23,   24,
       25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
       25,   35,   36,   37,   38,   39,   40,   25,   25,   25,
       41,   42,   43,    1,   44,    1,   45,   46,   47,   48,

       49,   50,   51,   52,   53,   25,   54,   55,   56,   57,
       58,   59,   60,   61,   62,   63,   64,   65,   25,   66,
       67,   25,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[68] =
    {   0,
        1,    2,    3,    1,    2,    2,    4,    2,    2,    2,
        1,    5,    6,    5,    5,    1,    2,    1,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        7,    8,    9,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5
    } ;

static const flex_int16_t yy_base[726] =
    {   0,
        0,    0,    0,    0,   65,   66,   72,   88,  100,  108,
      124,  178,   97,  149,  230,  252,  276,  318,  358,  406,
      153,  157, 1639, 1638, 1640, 1643,   81,  141, 1643, 1643,
     1643, 1643, 1598, 1643,  122, 1643, 1643, 1643,  151, 1597,
       63,  163,  127,  130,   29,  159,   98,  202,  177,  160,
      255,  181,  162,  201,   30,  107,  186,  198,  297,  257,
      247,  302,  221,  304,  303,  152, 1643,    0, 1643,    0,
        0, 1643,    0, 1643, 1643, 1643, 1643, 1643, 1643, 1643,
     1643,  105,  364,  374,    0, 1588, 1643,  378,  382,  294,
     1643, 1643,  374, 1643, 1643,  391,    0,  135, 1643,  195,

      229, 1643,  386, 1643, 1643,  435,  439, 1643, 1643, 1572,
     1573,    0, 1643,  443, 1593,  162,  289,  170,  197,  167,
      374,  266,  260,  408,  409,  275,  384,  416,  418,  453,
      421,  419,  420,  432,  425,  423,  223,  298,  433,  431,
      430,  375,  448,  385,  300,  434,  443,  445,  449,  453,
      451,  461,  459,  377,  462,  470,  466,  465,  472,  476,
      479,  478,  480,  483,  488,  489,  490,  493,  501,  492,
      491,  494,  503,  509,    0, 1643,    0,  376, 1643,  556,
        0, 1572,  561,  562,  559,  554, 1609, 1596, 1603, 1592,
        0,  531, 1594, 1606, 1597, 1602,  555,  583, 1576, 1572,

        0,  575,  579,  581,  556,  534,  550,  580,  565,  567,
      569,  570,  575, 1581,  574,  591,  571,  576,  619,  584,
      596,  586,  587,  594, 1580,  603,  589,  597,  602,  605,
      608,  611,  614,  615,  613,  616,  618,  621,  623,  624,
      627,  629,  515,  631,  633,  632,  636,  641,  645,  642,
     1579,  643,  649,  634,  656,  658,  659,  660,  661, 1578,
      663,  664,  662,  666, 1577,  668,  670,  673,  680,  675,
      677,  679,  674, 1576, 1559,  722,  724, 1585, 1592, 1581,
     1577, 1579, 1591, 1590,    0, 1576, 1572,  736, 1553, 1643,
     1589,  746,  718,  699,  700,  701,  731,  714,  718, 1563,

     1562,  715,  723, 1561,  724,  725,  775, 1560,  727,  750,
      730, 1559,  751,  728,  734, 1558,  753,  757, 1557,  754,
      758,  759,  761,  760,  763,  764,  770,  767, 1556,  766,
      827,  784,  769,  778,  801, 1555,  772,  805,  832, 1554,
      808,  809, 1553,  810, 1552,  768,  811,  814,  812,  817,
      818,  815,  821,  830,  833, 1551,  836,  838, 1550,  899,
      875, 1557, 1562, 1561, 1554, 1549, 1548, 1549, 1550, 1538,
      882, 1518, 1643,  870,  872, 1564, 1538,  851,  842, 1537,
      877,  878, 1536,  879,  885,  880,  930,  882,  902, 1535,
      840,  896, 1534, 1533,  905, 1532,  906, 1531,  883, 1530,

     1529,  908, 1528,  913,  914, 1511,  915,  945,  920, 1526,
     1525, 1524,  921,  922,  925, 1523,  926,  927,  928,  929,
      941,  933,  937,  871, 1522, 1521,  938,  935,  939,  940,
      948,  930, 1504, 1503,  994, 1519, 1521, 1534, 1521, 1548,
     1516, 1522, 1512, 1532, 1643,  990,  762, 1509,  965,  960,
      966,  969,  971,  970, 1010,  972,  976,  979,  978,  985,
      981, 1508, 1507,  987,  994, 1489,  995, 1021,  997, 1505,
     1504, 1000, 1503, 1001, 1502, 1007, 1006, 1005, 1008, 1010,
     1015, 1011, 1501, 1016, 1017, 1500, 1023, 1026, 1482, 1481,
     1063, 1515, 1530, 1514, 1528, 1643, 1498, 1500, 1500, 1492,

     1053, 1065, 1029, 1031, 1034, 1489, 1043, 1086, 1067, 1044,
     1045, 1056, 1488, 1046, 1052, 1047, 1065, 1465, 1062, 1643,
     1066, 1069, 1070, 1072, 1073, 1076, 1078, 1074, 1486, 1080,
     1088, 1077, 1485, 1086, 1089, 1462, 1461, 1126, 1119, 1501,
     1643, 1515, 1643, 1514, 1485, 1478, 1497, 1128, 1134, 1476,
     1475, 1474, 1097, 1136, 1473, 1107, 1111, 1112, 1472, 1471,
     1113, 1458, 1114, 1118, 1119, 1120, 1122, 1123, 1124, 1469,
     1125, 1468, 1130, 1135, 1467, 1466, 1453, 1452, 1165, 1497,
     1643, 1643, 1459, 1171,    0, 1173, 1175, 1177, 1461, 1179,
     1460, 1129, 1141, 1459, 1452, 1154, 1156, 1457, 1456, 1455,

     1454, 1157, 1158, 1163, 1453, 1446, 1445, 1194, 1643, 1194,
     1204, 1165, 1207, 1212, 1214, 1450, 1184, 1441, 1190, 1191,
     1448, 1194, 1159, 1439, 1438, 1219, 1206, 1463, 1450, 1457,
     1446,    0, 1226, 1466, 1228, 1440, 1464, 1221, 1438, 1204,
     1205, 1462, 1461, 1237, 1440, 1439, 1420, 1413, 1414, 1418,
     1240, 1242, 1244, 1643, 1395, 1220, 1643, 1249, 1402, 1396,
     1392, 1385, 1377, 1272, 1244, 1251, 1254, 1229, 1257, 1265,
     1266, 1261, 1175,    0,  864, 1259, 1643, 1261, 1643,  573,
     1263, 1643,  524,    0,  407,    0,  356, 1265,  342,    0,
        0,  242,    0, 1272, 1274, 1279, 1279, 1281, 1284, 1296,

       90, 1287, 1298, 1643, 1643, 1313, 1322, 1331, 1340, 1349,
     1358, 1367, 1376, 1385, 1394, 1403, 1408, 1415, 1424, 1433,
     1438, 1440, 1449, 1458, 1467
    } ;

static const flex_int16_t yy_def[726] =
    {   0,
      705,    1,  706,  706,  707,  707,  708,  708,  709,  709,
      710,  710,  711,  711,  712,  712,  713,  713,  714,  714,
      715,  715,  716,  716,  705,  705,  705,  705,  705,  705,
      705,  705,  717,  705,  717,  705,  705,  705,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  705,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  705,  718,  705,  719,
      720,  705,  720,  705,  705,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  721,  721,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  722,  722,  705,  722,

      722,  705,  705,  705,  705,  705,  705,  705,  705,  705,
      705,  723,  705,  705,  717,  705,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  705,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  718,  705,  720,  705,  705,  705,
      721,  721,  705,  705,  705,  705,  705,  705,  705,  705,
      722,  722,  722,  722,  722,  722,  705,  705,  705,  705,

      723,  705,  717,  705,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  705,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  721,  705,  705,  705,  705,  705,
      705,  705,  705,  722,  722,  722,  722,  705,  705,  705,
      705,  717,  705,  717,  717,  717,  717,  717,  717,  717,

      717,  717,  717,  717,  717,  717,  705,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      724,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  725,
      705,  705,  705,  705,  705,  705,  705,  722,  722,  722,
      705,  705,  705,  717,  717,  705,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  705,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,

      717,  717,  717,  717,  717,  705,  717,  705,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  705,  721,  705,  705,  705,  705,  705,  705,
      705,  722,  722,  722,  705,  717,  705,  717,  717,  717,
      717,  717,  717,  717,  705,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  705,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  705,  721,
      705,  705,  705,  705,  705,  705,  705,  722,  722,  722,

      717,  705,  717,  717,  717,  717,  717,  705,  705,  717,
      717,  717,  717,  717,  717,  717,  717,  705,  717,  705,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  705,  721,  705,  705,  705,
      705,  705,  705,  705,  722,  722,  722,  717,  705,  717,
      717,  717,  717,  705,  717,  717,  717,  717,  717,  717,
      717,  705,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  705,  721,  705,  705,
      705,  705,  722,  722,  722,  717,  705,  705,  717,  705,
      717,  717,  717,  717,  705,  717,  717,  717,  717,  717,

      717,  717,  717,  717,  717,  705,  721,  705,  705,  722,
      722,  717,  705,  705,  705,  717,  717,  705,  717,  717,
      717,  717,  717,  705,  721,  705,  722,  722,  722,  722,
      722,  722,  717,  705,  705,  717,  705,  717,  717,  717,
      717,  705,  721,  705,  722,  722,  722,  722,  722,  722,
      717,  705,  705,  705,  717,  717,  705,  705,  722,  722,
      722,  722,  722,  722,  717,  705,  705,  717,  705,  722,
      722,  722,  722,  722,  722,  705,  705,  705,  705,  717,
      705,  705,  722,  722,  722,  722,  722,  705,  722,  722,
      722,  705,  722,  705,  705,  705,  705,  705,  705,  705,

      705,  705,  705,  705,    0,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705
    } ;

static const flex_int16_t yy_nxt[1711] =
    {   0,
       26,   27,   28,   27,   27,   26,   29,   30,   31,   32,
       26,   33,   34,   35,   35,   36,   37,   38,   39,   40,
       40,   41,   40,   42,   40,   40,   40,   43,   40,   40,
       44,   45,   46,   40,   40,   47,   40,   40,   40,   40,
       48,   26,   26,   40,   49,   50,   51,   52,   53,   54,
       40,   55,   56,   57,   58,   59,   60,   61,   62,   40,
       63,   64,   65,   66,   40,   40,   40,   67,   67,  116,
      116,   69,   69,   72,   72,   73,   72,   67,   74,   67,
       75,   76,  114,  114,  114,  114,  126,  147,   77,   72,
       72,   73,   72,   67,   74,   67,   75,   76,   88,   89,

       88,   88,   67,  116,   77,  702,   70,   70,   79,   80,
       67,  120,   81,   82,   82,   83,   79,   80,  178,  178,
       81,   82,   82,   83,   67,   84,   84,   84,   84,   67,
       67,   67,   67,   67,   67,  117,  117,   90,  116,   67,
       67,   67,  114,  114,  114,  114,  129,  116,  192,  192,
       88,   89,   88,   88,  106,  107,  106,  106,  106,  107,
      106,  106,  116,  148,   67,   67,   67,  116,  108,  109,
      116,  123,  108,  109,  125,  202,  202,   86,   67,   84,
       84,   84,   84,   67,   67,   67,   67,   67,   67,   90,
      124,  116,  116,   67,   67,   67,  127,  110,  121,  116,

      116,  110,  116,  116,  174,  128,  130,  116,  111,  118,
      116,  122,  111,  207,  119,  130,  130,  116,   67,   67,
       67,  116,  141,  135,  131,  139,  116,  142,  193,  140,
      205,   86,   67,  194,  149,  132,   92,  116,  116,  133,
      134,  116,  150,   93,   93,  143,   94,  206,   93,   93,
       93,   93,   93,   93,   67,  144,  151,  694,   92,  145,
      195,  116,  146,  116,  196,   93,   93,  227,   94,  164,
       93,   93,   93,   93,   93,   93,   95,   95,   67,   95,
       95,   95,   96,   95,   95,   95,   95,  116,   95,   98,
       98,   95,   99,   95,  100,  116,  157,  116,  184,  136,

      116,  155,  203,  203,  204,  158,  116,  184,  184,  137,
      159,  209,  138,  101,  156,  116,  210,   95,   95,   95,
       67,   95,   95,   95,   96,   95,   95,   95,   95,  116,
       95,   98,   98,   95,   99,   95,  100,  116,  116,  215,
      116,  152,  116,  116,  116,  153,  160,  170,  165,  171,
      161,  172,  166,  228,  162,  101,  167,  237,  154,   95,
       67,  168,  163,  693,  169,  179,  179,  179,  179,  173,
      103,  103,  103,  103,  104,  180,  180,  180,  180,  183,
      183,  183,  183,  183,  183,  183,  183,  185,  185,  178,
      178,  691,  185,  185,  185,  185,  185,  185,  197,  197,

      197,  197,  103,  103,  103,  103,  103,  103,   67,  186,
      216,  208,  187,  188,  116,  116,  189,  116,  103,  103,
      103,  103,  104,  233,  116,  116,  190,  251,  690,  236,
      197,  197,  197,  197,  197,  197,  198,  198,  198,  198,
      198,  198,  198,  198,  114,  114,  114,  114,  116,  116,
      103,  103,  103,  103,  103,  103,  116,  219,  116,  116,
      116,  116,  211,  116,  212,  116,  219,  219,  220,  213,
      116,  116,  116,  116,  116,  214,  218,  221,  217,  223,
      229,  226,  222,  116,  224,  116,  225,  230,  116,  116,
      232,  116,  231,  116,  241,  234,  238,  239,  244,  116,

      245,  116,  116,  235,  240,  116,  116,  242,  246,  243,
      116,  247,  116,  255,  249,  254,  116,  252,  116,  116,
      116,  250,  248,  116,  256,  260,  253,  259,  116,  116,
      116,  116,  116,  116,  116,  263,  257,  261,  258,  267,
      266,  116,  262,  116,  192,  192,  689,  268,  271,  116,
      265,  264,  269,  270,  272,  116,  274,  180,  180,  180,
      180,  273,  183,  183,  183,  183,  276,  288,  288,  288,
      288,  331,  277,  277,  116,  276,  276,  277,  277,  277,
      277,  277,  277,  278,  198,  198,  198,  198,  202,  202,
      116,  279,  292,  292,  293,  293,  116,  295,  296,  288,

      288,  288,  288,  288,  288,  116,  297,  116,  294,  116,
      116,  116,  304,  116,  116,  116,  116,  291,  301,  116,
      116,  302,  303,  307,  116,  298,  116,  116,  305,  116,
      299,  116,  307,  307,  116,  300,  116,  116,  306,  311,
      309,  312,  116,  116,  308,  116,  310,  313,  116,  317,
      315,  116,  316,  116,  116,  116,  116,  318,  116,  314,
      321,  116,  322,  116,  116,  323,  324,  116,  320,  116,
      319,  116,  116,  116,  116,  327,  116,  330,  325,  332,
      333,  116,  116,  116,  329,  116,  328,  326,  335,  116,
      337,  339,  334,  338,  336,  341,  116,  340,  116,  116,

      116,  116,  116,  116,  116,  343,  116,  344,  116,  350,
      116,  345,  347,  116,  116,  116,  342,  116,  351,  116,
      116,  346,  359,  353,  352,  348,  361,  349,  356,  354,
      355,  376,  376,  357,  358,  361,  361,  185,  185,  116,
      116,  116,  185,  185,  185,  185,  185,  185,  371,  371,
      371,  371,  380,  377,  116,  116,  379,  374,  116,  375,
      375,  378,  382,  116,  116,  116,  383,  116,  116,  385,
      116,  116,  392,  386,  116,  502,  502,  381,  384,  387,
      371,  371,  371,  371,  371,  371,  116,  388,  387,  387,
      116,  116,  390,  116,  116,  393,  391,  116,  116,  116,

      116,  116,  389,  116,  116,  395,  116,  116,  116,  116,
      116,  421,  116,  394,  396,  399,  397,  403,  116,  398,
      414,  400,  402,  404,  116,  401,  405,  406,  406,  411,
      406,  406,  406,  406,  406,  406,  406,  406,  410,  406,
      412,  116,  406,  406,  406,  116,  416,  413,  116,  116,
      116,  116,  116,  419,  116,  116,  418,  116,  116,  427,
      424,  116,  415,  422,  428,  426,  420,  408,  406,  406,
      116,  423,  116,  116,  429,  409,  116,  425,  116,  435,
      116,  430,  116,  446,  446,  375,  375,  449,  435,  435,
      432,  116,  458,  417,  371,  371,  371,  371,  431,  433,

      433,  687,  433,  433,  433,  433,  433,  433,  433,  433,
      116,  116,  116,  448,  433,  433,  433,  116,  116,  116,
      116,  450,  116,  116,  452,  116,  371,  371,  371,  371,
      371,  371,  482,  453,  455,  454,  116,  456,  451,  433,
      433,  433,  116,  455,  455,  116,  116,  457,  116,  462,
      461,  459,  460,  116,  116,  116,  463,  464,  202,  202,
      116,  116,  116,  465,  469,  116,  116,  116,  116,  116,
      116,  467,  471,  116,  468,  116,  467,  116,  116,  116,
      116,  116,  470,  481,  472,  476,  488,  480,  116,  473,
      474,  475,  483,  477,  485,  478,  487,  484,  491,  479,

      116,  466,  486,  501,  501,  116,  116,  491,  491,  116,
      116,  116,  116,  503,  508,  507,  116,  505,  116,  116,
      504,  116,  509,  508,  508,  116,  513,  116,  514,  510,
      116,  506,  214,  512,  116,  116,  520,  116,  517,  511,
      116,  116,  516,  515,  522,  116,  116,  116,  116,  526,
      116,  116,  519,  523,  524,  116,  116,  116,  529,  521,
      527,  116,  525,  116,  548,  533,  116,  538,  528,  116,
      535,  116,  530,  531,  116,  539,  538,  538,  549,  549,
      554,  554,  532,  116,  116,  116,  116,  116,  534,  550,
      508,  553,  116,  116,  552,  560,  116,  551,  509,  508,

      508,  558,  116,  559,  555,  116,  116,  556,  557,  116,
      116,  561,  116,  116,  116,  565,  116,  116,  116,  567,
      116,  569,  568,  564,  563,  570,  116,  566,  116,  116,
      538,  571,  579,  579,  572,  574,  573,  116,  539,  538,
      538,  586,  586,  576,  587,  587,  588,  116,  575,  590,
      590,  116,  116,  116,  116,  591,  593,  589,  116,  116,
      116,  594,  116,  116,  116,  116,  596,  598,  116,  116,
      116,  597,  602,  592,  603,  116,  599,  604,  608,  608,
      601,  116,  600,  605,  611,  611,  612,  612,  613,  613,
      614,  614,  615,  615,  116,  616,  116,  116,  116,  116,

      619,  633,  617,  116,  620,  116,  623,  626,  626,  686,
      622,  621,  627,  116,  641,  628,  629,  611,  611,  630,
      634,  634,  587,  587,  116,  614,  614,  635,  635,  631,
      116,  116,  644,  644,  116,  645,  654,  636,  638,  651,
      651,  653,  653,  646,  116,  116,  632,  639,  640,  656,
      658,  658,  655,  665,  665,  666,  666,  667,  667,  676,
      116,  116,  669,  669,  677,  677,  116,  678,  678,  116,
      681,  681,  688,  688,  678,  678,  681,  681,  692,  692,
      116,  668,  680,  685,  116,  695,  695,  696,  696,  697,
      697,  698,  699,  699,  700,  700,  679,  701,  701,  682,

      703,  703,  684,  679,  683,  682,  697,  697,  675,  700,
      700,  704,  704,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   71,   71,   71,   71,   71,   71,   71,   71,   71,
       78,   78,   78,   78,   78,   78,   78,   78,   78,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   91,   91,   91,
       91,   91,   91,   91,   91,   91,   97,   97,   97,   97,
       97,   97,   97,   97,   97,  102,  102,  102,  102,  102,
      102,  102,  102,  102,  105,  105,  105,  105,  105,  105,

      105,  105,  105,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  115,  674,  115,  175,  175,  673,  672,  175,
      175,  175,  671,  175,  176,  176,  176,  176,  176,  176,
      176,  176,  176,  177,  670,  116,  664,  177,  177,  177,
      177,  177,  181,  181,  191,  663,  191,  662,  191,  201,
      201,  661,  201,  201,  201,  201,  201,  201,  407,  407,
      660,  407,  407,  407,  407,  407,  407,  434,  434,  659,
      434,  434,  434,  434,  434,  434,  657,  657,  116,  654,
      116,  652,  650,  649,  648,  647,  643,  642,  116,  637,
      116,  625,  624,  116,  116,  116,  116,  116,  618,  116,

      116,  116,  610,  609,  607,  606,  116,  116,  116,  116,
      595,  116,  116,  116,  116,  116,  116,  585,  584,  583,
      582,  581,  580,  578,  577,  116,  116,  562,  116,  116,
      547,  546,  545,  544,  543,  542,  541,  540,  537,  536,
      116,  116,  116,  116,  116,  116,  518,  116,  116,  116,
      500,  499,  498,  497,  496,  495,  494,  493,  492,  490,
      489,  116,  116,  116,  116,  116,  116,  466,  116,  116,
      116,  116,  116,  116,  116,  116,  116,  116,  116,  447,
      445,  444,  443,  442,  441,  440,  439,  438,  437,  436,
      116,  116,  116,  116,  116,  116,  116,  116,  116,  116,

      116,  116,  116,  116,  373,  372,  370,  369,  368,  367,
      366,  365,  364,  363,  362,  360,  116,  116,  116,  116,
      116,  116,  290,  289,  287,  286,  285,  284,  283,  282,
      281,  280,  275,  116,  200,  199,  182,  116,  116,  705,
      113,  113,   25,  705,  705,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,

      705,  705,  705,  705,  705,  705,  705,  705,  705,  705
    } ;

static const flex_int16_t yy_chk[1711] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    5,    6,   45,
       55,    5,    6,    7,    7,    7,    7,    7,    7,    7,
        7,    7,   27,   27,   27,   27,   45,   55,    7,    8,
        8,    8,    8,    8,    8,    8,    8,    8,   13,   13,

       13,   13,    9,   41,    8,  701,    5,    6,    9,    9,
       10,   41,    9,    9,    9,    9,   10,   10,   82,   82,
       10,   10,   10,   10,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   35,   35,   13,   47,   11,
       11,   11,   28,   28,   28,   28,   47,   56,   98,   98,
       14,   14,   14,   14,   21,   21,   21,   21,   22,   22,
       22,   22,   35,   56,   11,   11,   11,   43,   21,   21,
       44,   43,   22,   22,   44,  116,  116,   11,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   14,
       43,   39,   66,   12,   12,   12,   46,   21,   42,   46,

       50,   22,   53,   42,   66,   46,   48,  120,   21,   39,
      118,   42,   22,  120,   39,   48,   48,   49,   12,   12,
       12,   52,   53,   50,   49,   52,   57,   53,  100,   52,
      118,   12,   15,  100,   57,   49,   15,  119,   58,   49,
       49,   54,   58,   15,   15,   54,   15,  119,   15,   15,
       15,   15,   15,   15,   16,   54,   58,  692,   16,   54,
      101,   63,   54,  137,  101,   16,   16,  137,   16,   63,
       16,   16,   16,   16,   16,   16,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   61,   17,   17,
       17,   17,   17,   17,   17,   51,   61,   60,   90,   51,

      123,   60,  117,  117,  117,   61,  122,   90,   90,   51,
       61,  122,   51,   17,   60,  126,  123,   17,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,  117,
       18,   18,   18,   18,   18,   18,   18,   59,  138,  126,
      145,   59,   62,   65,   64,   59,   62,   65,   64,   65,
       62,   65,   64,  138,   62,   18,   64,  145,   59,   18,
       19,   64,   62,  689,   64,   83,   83,   83,   83,   65,
       19,   19,   19,   19,   19,   84,   84,   84,   84,   88,
       88,   88,   88,   89,   89,   89,   89,   93,   93,  178,
      178,  687,   93,   93,   93,   93,   93,   93,  103,  103,

      103,  103,   19,   19,   19,   19,   19,   19,   20,   96,
      127,  121,   96,   96,  121,  142,   96,  154,   20,   20,
       20,   20,   20,  142,  127,  144,   96,  154,  685,  144,
      103,  103,  103,  103,  103,  103,  106,  106,  106,  106,
      107,  107,  107,  107,  114,  114,  114,  114,  124,  125,
       20,   20,   20,   20,   20,   20,  128,  130,  129,  132,
      133,  131,  124,  136,  124,  135,  130,  130,  131,  125,
      141,  140,  134,  139,  146,  125,  129,  132,  128,  134,
      139,  136,  133,  147,  134,  148,  135,  140,  143,  149,
      141,  151,  140,  150,  148,  143,  146,  146,  150,  153,

      150,  152,  155,  143,  147,  158,  157,  148,  151,  149,
      156,  152,  159,  158,  153,  157,  160,  155,  162,  161,
      163,  153,  152,  164,  159,  162,  156,  161,  165,  166,
      167,  171,  170,  168,  172,  165,  160,  163,  160,  168,
      167,  169,  164,  173,  192,  192,  683,  169,  171,  174,
      166,  165,  170,  170,  172,  243,  174,  180,  180,  180,
      180,  173,  183,  183,  183,  183,  184,  197,  197,  197,
      197,  243,  185,  185,  206,  184,  184,  185,  185,  185,
      185,  185,  185,  186,  198,  198,  198,  198,  202,  202,
      207,  186,  203,  203,  204,  204,  205,  206,  207,  197,

      197,  197,  197,  197,  197,  209,  208,  210,  205,  211,
      212,  217,  216,  680,  215,  213,  218,  202,  212,  203,
      208,  213,  215,  219,  220,  209,  222,  223,  217,  227,
      210,  216,  219,  219,  224,  211,  221,  228,  218,  223,
      221,  224,  229,  226,  220,  230,  222,  226,  231,  229,
      227,  232,  228,  235,  233,  234,  236,  230,  237,  226,
      233,  238,  234,  239,  240,  235,  236,  241,  232,  242,
      231,  244,  246,  245,  254,  239,  247,  242,  237,  244,
      245,  248,  250,  252,  241,  249,  240,  238,  247,  253,
      249,  252,  246,  250,  248,  254,  255,  253,  256,  257,

      258,  259,  263,  261,  262,  256,  264,  257,  266,  263,
      267,  258,  261,  268,  273,  270,  255,  271,  264,  272,
      269,  259,  273,  267,  266,  261,  276,  262,  270,  268,
      269,  293,  293,  271,  272,  276,  276,  277,  277,  294,
      295,  296,  277,  277,  277,  277,  277,  277,  288,  288,
      288,  288,  297,  294,  298,  302,  296,  292,  299,  292,
      292,  295,  299,  303,  305,  306,  302,  309,  314,  305,
      311,  297,  314,  306,  315,  447,  447,  298,  303,  307,
      288,  288,  288,  288,  288,  288,  292,  309,  307,  307,
      310,  313,  311,  317,  320,  315,  313,  318,  321,  322,

      324,  323,  310,  325,  326,  318,  330,  328,  346,  333,
      327,  346,  337,  317,  320,  323,  321,  327,  334,  322,
      337,  324,  326,  328,  332,  325,  330,  331,  331,  333,
      331,  331,  331,  331,  331,  331,  331,  331,  332,  331,
      334,  335,  331,  331,  331,  338,  339,  335,  341,  342,
      344,  347,  349,  342,  348,  352,  341,  350,  351,  352,
      349,  353,  338,  347,  353,  351,  344,  331,  331,  331,
      354,  348,  339,  355,  354,  331,  357,  350,  358,  361,
      391,  355,  379,  374,  374,  375,  375,  379,  361,  361,
      358,  378,  391,  339,  371,  371,  371,  371,  357,  360,

      360,  675,  360,  360,  360,  360,  360,  360,  360,  360,
      374,  424,  375,  378,  360,  360,  360,  381,  382,  384,
      386,  381,  388,  399,  384,  385,  371,  371,  371,  371,
      371,  371,  424,  385,  387,  386,  392,  388,  382,  360,
      360,  360,  389,  387,  387,  395,  397,  389,  402,  399,
      397,  392,  395,  404,  405,  407,  402,  404,  408,  408,
      409,  413,  414,  405,  413,  415,  417,  418,  419,  420,
      432,  407,  415,  422,  409,  428,  409,  423,  427,  429,
      430,  421,  414,  423,  417,  421,  432,  422,  431,  418,
      419,  420,  427,  421,  429,  421,  431,  428,  435,  421,

      450,  408,  430,  446,  446,  449,  451,  435,  435,  452,
      454,  453,  456,  449,  455,  454,  457,  452,  459,  458,
      450,  461,  455,  455,  455,  460,  459,  464,  460,  456,
      446,  453,  451,  458,  465,  467,  468,  469,  465,  457,
      472,  474,  464,  461,  472,  478,  477,  476,  479,  478,
      480,  482,  467,  474,  476,  481,  484,  485,  480,  469,
      479,  468,  477,  487,  501,  485,  488,  491,  479,  503,
      488,  504,  481,  482,  505,  491,  491,  491,  502,  502,
      509,  509,  484,  507,  510,  511,  514,  516,  487,  503,
      508,  507,  515,  501,  505,  516,  512,  504,  508,  508,

      508,  514,  519,  515,  510,  517,  521,  511,  512,  522,
      523,  517,  524,  525,  528,  522,  526,  532,  527,  524,
      530,  526,  525,  521,  519,  527,  534,  523,  531,  535,
      538,  528,  539,  539,  530,  532,  531,  553,  538,  538,
      538,  548,  548,  535,  549,  549,  549,  556,  534,  554,
      554,  557,  558,  561,  563,  556,  558,  553,  564,  565,
      566,  561,  567,  568,  569,  571,  563,  565,  548,  592,
      573,  564,  569,  557,  571,  574,  566,  573,  579,  579,
      568,  593,  567,  574,  584,  584,  586,  586,  587,  587,
      588,  588,  590,  590,  596,  592,  597,  602,  603,  623,

      596,  612,  593,  604,  597,  612,  604,  608,  608,  673,
      603,  602,  610,  586,  623,  610,  610,  611,  611,  610,
      613,  613,  614,  614,  617,  614,  614,  615,  615,  610,
      619,  620,  626,  626,  622,  627,  638,  617,  619,  633,
      633,  635,  635,  627,  640,  641,  611,  620,  622,  641,
      644,  644,  640,  651,  651,  652,  652,  653,  653,  665,
      656,  638,  658,  658,  666,  666,  633,  667,  667,  668,
      669,  669,  676,  676,  678,  678,  681,  681,  688,  688,
      651,  656,  668,  672,  665,  694,  694,  695,  695,  696,
      696,  696,  697,  697,  698,  698,  667,  699,  699,  669,

      702,  702,  671,  678,  670,  681,  700,  700,  664,  700,
      700,  703,  703,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  707,  707,  707,  707,  707,  707,  707,  707,
      707,  708,  708,  708,  708,  708,  708,  708,  708,  708,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  710,
      710,  710,  710,  710,  710,  710,  710,  710,  711,  711,
      711,  711,  711,  711,  711,  711,  711,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  714,  714,  714,  714,  714,
      714,  714,  714,  714,  715,  715,  715,  715,  715,  715,

      715,  715,  715,  716,  716,  716,  716,  716,  716,  716,
      716,  716,  717,  663,  717,  718,  718,  662,  661,  718,
      718,  718,  660,  718,  719,  719,  719,  719,  719,  719,
      719,  719,  719,  720,  659,  655,  650,  720,  720,  720,
      720,  720,  721,  721,  722,  649,  722,  648,  722,  723,
      723,  647,  723,  723,  723,  723,  723,  723,  724,  724,
      646,  724,  724,  724,  724,  724,  724,  725,  725,  645,
      725,  725,  725,  725,  725,  725,  643,  642,  639,  637,
      636,  634,  631,  630,  629,  628,  625,  624,  621,  618,
      616,  607,  606,  605,  601,  600,  599,  598,  595,  594,

      591,  589,  583,  580,  578,  577,  576,  575,  572,  570,
      562,  560,  559,  555,  552,  551,  550,  547,  546,  545,
      544,  542,  540,  537,  536,  533,  529,  518,  513,  506,
      500,  499,  498,  497,  495,  494,  493,  492,  490,  489,
      486,  483,  475,  473,  471,  470,  466,  463,  462,  448,
      444,  443,  442,  441,  440,  439,  438,  437,  436,  434,
      433,  426,  425,  416,  412,  411,  410,  406,  403,  401,
      400,  398,  396,  394,  393,  390,  383,  380,  377,  376,
      372,  370,  369,  368,  367,  366,  365,  364,  363,  362,
      359,  356,  345,  343,  340,  336,  329,  319,  316,  312,

      308,  304,  301,  300,  291,  289,  287,  286,  284,  283,
      282,  281,  280,  279,  278,  275,  274,  265,  260,  251,
      225,  214,  200,  199,  196,  195,  194,  193,  190,  189,
      188,  187,  182,  115,  111,  110,   86,   40,   33,   25,
       24,   23,  705,  705,  705,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,

      705,  705,  705,  705,  705,  705,  705,  705,  705,  705
    } ;

#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yyg->yy_full_match; /* restore poss. backed-over text */ \
yyg->yy_lp = yyg->yy_full_lp; /* restore orig. accepting pos. */ \
yyg->yy_state_ptr = yyg->yy_full_state; /* restore orig. state */ \
yy_current_state = *yyg->yy_state_ptr; /* restore curr. state */ \
++yyg->yy_lp; \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "scanner.l"
/*
 * Copyright (c) 1999-2008 NOVELL (All rights reserved)
 * Copyright (c) 2010, Canonical, Ltd.
 *
 * This file is dual licensed. It has been published under both the
 * LGPL and GPL licensed included below.
 *
 * Historical context of the Licensing.
 *
 * This code was originally authored by
 * Matt Barringer at Immunix. Novell bought Immunix and as part of the
 * releasing of AppArmor merged libaalogparse (containing the files
 * aalogparse.h, grammer.y, libaalogparse.c, parser.h, and Makefile.am)
 * with libapparmor. libaalogparse was originally licensed under the
 * GPL and libapparmor under the LGPL. As part of the releasing
 * AppArmor to the broader community. Novell (the copyright holder)
 * relicensed the libaalogparse files as LGPL. This included this
 * file scanner.l.
 *
 * Unfortunately this file was published in different places under
 * different licenses either GPL or LGPL. The GPL version of scanner.l was
 * mistakenly pulled in to the new AppArmor repo and published as such
 * but the file also existed and was published under the LGPL. Becuase
 * this file has been published under both licenses and may have be
 * in use one or the other license it will remain licensed under both.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2.1 of the GNU Lesser General
 * Public License published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public
 * License published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#line 63 "scanner.l"

#include "grammar.h"
#include <aalogparse.h>
#include "parser.h"

#include <assert.h>

#define YY_NO_INPUT

void string_buf_reset(struct string_buf* char_buf)
{
	/* rewind buffer to zero, possibly doing initial allocation too */
	char_buf->buf_len = 0;
	if (char_buf->buf == NULL) {
		char_buf->buf_alloc = 128;
		char_buf->buf = malloc(char_buf->buf_alloc);
		assert(char_buf->buf != NULL);
	}
	/* always start with a valid but empty string */
	char_buf->buf[0] = '\0';
}

void string_buf_append(struct string_buf* char_buf, unsigned int length, char *text)
{
	unsigned int current_length = char_buf->buf_len;

	/* handle calling ..._append before ..._reset */
	if (char_buf->buf == NULL) string_buf_reset(char_buf);

	char_buf->buf_len += length;
	/* expand allocation if this append would exceed the allocation */
	while (char_buf->buf_len >= char_buf->buf_alloc) {
		// TODO: overflow?
		char_buf->buf_alloc *= 2;
		char_buf->buf = realloc(char_buf->buf, char_buf->buf_alloc);
		assert(char_buf->buf != NULL);
	}
	/* copy and unconditionally terminate */
	memcpy(char_buf->buf+current_length, text, length);
	char_buf->buf[char_buf->buf_len] = '\0';
}

#line 1410 "scanner.c"
/* New message types */
/* Key tokens */
/* network addrs */
/* syslog tokens */

#line 1416 "scanner.c"

#define INITIAL 0
#define single_quoted_string 1
#define quoted_string 2
#define sub_id 3
#define audit_id 4
#define hostname 5
#define dmesg_timestamp 6
#define safe_string 7
#define audit_types 8
#define ip_addr 9
#define other_audit 10
#define unknown_message 11

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE struct string_buf*

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    yy_state_type *yy_state_buf;
    yy_state_type *yy_state_ptr;
    char *yy_full_match;
    int yy_lp;

    /* These are only needed for trailing context rules,
     * but there's no conditional variable for that yet. */
    int yy_looking_for_trail_begin;
    int yy_full_lp;
    int *yy_full_state;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

    static void yy_push_state ( int _new_state , yyscan_t yyscanner);
    
    static void yy_pop_state ( yyscan_t yyscanner );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! yyg->yy_state_buf )
            yyg->yy_state_buf = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  , yyscanner);
            if ( ! yyg->yy_state_buf )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 245 "scanner.l"


#line 248 "scanner.l"
yy_flex_debug = 0;



#line 1726 "scanner.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;

		yyg->yy_state_ptr = yyg->yy_state_buf;
		*yyg->yy_state_ptr++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 706 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*yyg->yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1643 );

yy_find_action:
		yy_current_state = *--yyg->yy_state_ptr;
		yyg->yy_lp = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yyg->yy_lp && yyg->yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yyg->yy_lp];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     yyg->yy_looking_for_trail_begin )
					{
					if ( yy_act == yyg->yy_looking_for_trail_begin )
						{
						yyg->yy_looking_for_trail_begin = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					yyg->yy_looking_for_trail_begin = yy_act & ~YY_TRAILING_MASK;
					yyg->yy_looking_for_trail_begin |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					yyg->yy_full_match = yy_cp;
					yyg->yy_full_state = yyg->yy_state_ptr;
					yyg->yy_full_lp = yyg->yy_lp;
					break;
					}
				++yyg->yy_lp;
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--yyg->yy_state_ptr;
			yyg->yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 252 "scanner.l"
{ /* Skip whitespace */ }
	YY_BREAK

case 2:
YY_RULE_SETUP
#line 255 "scanner.l"
{ yylval->t_str = strdup(yytext); return(TOK_AUDIT_DIGITS);}
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 256 "scanner.l"
{ yy_pop_state(yyscanner); return(TOK_COLON); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 257 "scanner.l"
{ return(TOK_COLON); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 258 "scanner.l"
{ return(TOK_PERIOD); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 259 "scanner.l"
{ return(TOK_OPEN_PAREN); }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 260 "scanner.l"
{ yy_pop_state(yyscanner); return(TOK_CLOSE_PAREN); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 261 "scanner.l"
{ BEGIN(unknown_message); yyless(0); /* dump the rest */ }
	YY_BREAK


case 9:
YY_RULE_SETUP
#line 265 "scanner.l"
{ return(TOK_OPEN_PAREN); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 266 "scanner.l"
{ BEGIN(INITIAL); return(TOK_CLOSE_PAREN); }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 267 "scanner.l"
{ }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 268 "scanner.l"
{ string_buf_reset(yyextra); BEGIN(quoted_string); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 269 "scanner.l"
{
			yylval->t_str = strdup(yytext);
			BEGIN(INITIAL);
			return(TOK_ID);
		}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 274 "scanner.l"
{ return(TOK_EQUALS); }
	YY_BREAK

case 15:
YY_RULE_SETUP
#line 277 "scanner.l"
{ string_buf_reset(yyextra); BEGIN(quoted_string); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 278 "scanner.l"
{ /* End of the quoted string */
				BEGIN(INITIAL);
				yylval->t_str = strdup(yyextra->buf);
				return(TOK_QUOTED_STRING);
			}
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 285 "scanner.l"
{ string_buf_append(yyextra, 1, &yytext[1]); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 287 "scanner.l"
{ string_buf_append(yyextra, yyleng, yytext); }
	YY_BREAK

case 19:
YY_RULE_SETUP
#line 290 "scanner.l"
{ string_buf_reset(yyextra); BEGIN(quoted_string); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 291 "scanner.l"
{ yylval->t_str = hex_to_string(yytext); BEGIN(INITIAL); return(TOK_HEXSTRING);}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 292 "scanner.l"
{ return(TOK_EQUALS); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 293 "scanner.l"
{ /* eek, error! try another state */ BEGIN(INITIAL); yyless(0); }
	YY_BREAK


case 23:
YY_RULE_SETUP
#line 297 "scanner.l"
{ yylval->t_str = strdup(yytext); yy_pop_state(yyscanner); return(TOK_IP_ADDR); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 298 "scanner.l"
{ return(TOK_EQUALS); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 299 "scanner.l"
{ /* eek, error! try another state */ BEGIN(INITIAL); yyless(0); }
	YY_BREAK


case 26:
YY_RULE_SETUP
#line 303 "scanner.l"
{ return(TOK_EQUALS); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 304 "scanner.l"
{ yylval->t_long = atol(yytext); BEGIN(INITIAL); return(TOK_DIGITS); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 305 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_REJECT); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 306 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_AUDIT); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 307 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_COMPLAIN); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 308 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_HINT); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 309 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_STATUS); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 310 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_ERROR); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 311 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_AA_REJECT); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 312 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_AA_AUDIT); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 313 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_AA_COMPLAIN); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 314 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_AA_HINT); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 315 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_AA_STATUS); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 316 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_AA_ERROR); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 317 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_LSM_AVC); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 318 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_USER_AVC); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 319 "scanner.l"
{ char *yptr = yytext;
			  while (*yptr && *yptr != '[')
			  	yptr++;
			  if (*yptr)
			  	yylval->t_long = atol(yptr + 1); /* skip '[' */
			  BEGIN(INITIAL);
			  return(TOK_TYPE_UNKNOWN);
			}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 327 "scanner.l"
{ yylval->t_str = strdup(yytext);
			      BEGIN(other_audit);
			      return(TOK_TYPE_OTHER);
			}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 331 "scanner.l"
{ BEGIN(unknown_message); yyless(0); /* dump the rest */ }
	YY_BREAK

case 45:
YY_RULE_SETUP
#line 334 "scanner.l"
{ return(TOK_EQUALS); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 335 "scanner.l"
{ yylval->t_long = atol(yytext); return(TOK_DIGITS); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 336 "scanner.l"
{ return(TOK_COLON); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 337 "scanner.l"
{ return(TOK_MINUS); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 338 "scanner.l"
{
			BEGIN(sub_id);
			return(TOK_OPEN_PAREN);
			}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 342 "scanner.l"
{ return(TOK_CLOSE_PAREN); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 343 "scanner.l"
{ return(TOK_PERIOD); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 344 "scanner.l"
{ return(TOK_QUESTION_MARK); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 345 "scanner.l"
{ return(TOK_SINGLE_QUOTE); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 346 "scanner.l"
{ return(TOK_NONE); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 349 "scanner.l"
{ BEGIN(audit_types); return(TOK_KEY_APPARMOR); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 350 "scanner.l"
{ BEGIN(audit_types); return(TOK_KEY_TYPE); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 351 "scanner.l"
{ return(TOK_KEY_MSG); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 352 "scanner.l"
{ return(TOK_KEY_OPERATION); }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 353 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_NAME); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 354 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_NAME2); }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 355 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_NAMESPACE); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 356 "scanner.l"
{ return(TOK_KEY_MASK); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 357 "scanner.l"
{ return(TOK_KEY_DENIED_MASK); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 358 "scanner.l"
{ return(TOK_KEY_REQUESTED_MASK); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 359 "scanner.l"
{ return(TOK_KEY_DENIED_MASK); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 360 "scanner.l"
{ return(TOK_KEY_REQUESTED_MASK); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 361 "scanner.l"
{ BEGIN(sub_id); return(TOK_KEY_ATTRIBUTE); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 362 "scanner.l"
{ return(TOK_KEY_TASK); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 363 "scanner.l"
{ return(TOK_KEY_PARENT); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 364 "scanner.l"
{ return(TOK_KEY_MAGIC_TOKEN); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 365 "scanner.l"
{ return(TOK_KEY_INFO); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 366 "scanner.l"
{ return(TOK_KEY_PEER_INFO); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 367 "scanner.l"
{ return(TOK_KEY_PID); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 368 "scanner.l"
{ return(TOK_KEY_PEER_PID); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 369 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_PROFILE); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 370 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_PEER_PROFILE); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 371 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_LABEL); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 372 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_PEER_LABEL); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 373 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_PEER_LABEL); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 374 "scanner.l"
{ return(TOK_KEY_FAMILY); }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 375 "scanner.l"
{ return(TOK_KEY_SOCK_TYPE); }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 376 "scanner.l"
{ return(TOK_KEY_PROTOCOL); }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 377 "scanner.l"
{ return(TOK_KEY_ERROR); }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 378 "scanner.l"
{ return(TOK_KEY_FSUID); }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 379 "scanner.l"
{ return(TOK_KEY_FSUID_UPPER); }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 380 "scanner.l"
{ return(TOK_KEY_OUID); }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 381 "scanner.l"
{ return(TOK_KEY_OUID_UPPER); }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 382 "scanner.l"
{ return(TOK_KEY_UID); }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 383 "scanner.l"
{ return(TOK_KEY_AUID); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 384 "scanner.l"
{ return(TOK_KEY_SAUID); }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 385 "scanner.l"
{ return(TOK_KEY_SES); }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 386 "scanner.l"
{ return(TOK_KEY_HOSTNAME); }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 387 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_ADDR); }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 388 "scanner.l"
{ return(TOK_KEY_TERMINAL); }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 389 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_EXE); }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 390 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_COMM); }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 391 "scanner.l"
{ return(TOK_KEY_CAPABILITY); }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 392 "scanner.l"
{ return(TOK_KEY_CAPNAME); }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 393 "scanner.l"
{ return(TOK_KEY_OFFSET); }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 394 "scanner.l"
{ return(TOK_KEY_TARGET); }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 395 "scanner.l"
{ yy_push_state(ip_addr, yyscanner); return(TOK_KEY_LADDR); }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 396 "scanner.l"
{ yy_push_state(ip_addr, yyscanner); return(TOK_KEY_LADDR); }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 397 "scanner.l"
{ yy_push_state(ip_addr, yyscanner); return(TOK_KEY_FADDR); }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 398 "scanner.l"
{ yy_push_state(ip_addr, yyscanner); return(TOK_KEY_FADDR); }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 399 "scanner.l"
{ return(TOK_KEY_LPORT); }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 400 "scanner.l"
{ return(TOK_KEY_LPORT); }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 401 "scanner.l"
{ return(TOK_KEY_FPORT); }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 402 "scanner.l"
{ return(TOK_KEY_FPORT); }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 403 "scanner.l"
{ return(TOK_KEY_BUS); }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 404 "scanner.l"
{ return(TOK_KEY_PATH); }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 405 "scanner.l"
{ return(TOK_KEY_INTERFACE); }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 406 "scanner.l"
{ return(TOK_KEY_MEMBER); }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 407 "scanner.l"
{ return(TOK_KEY_MEMBER); }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 408 "scanner.l"
{ BEGIN(sub_id); return(TOK_KEY_SIGNAL); }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 409 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_PEER); }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 410 "scanner.l"
{ return(TOK_KEY_FSTYPE); }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 411 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_FLAGS); }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 412 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_SRCNAME); }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 413 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_UNIX_PEER_ADDR); }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 414 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_EXECPATH); }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 415 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_CLASS); }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 417 "scanner.l"
{ BEGIN(dmesg_timestamp); return(TOK_SOCKLOGD_KERNEL); }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 418 "scanner.l"
{ BEGIN(dmesg_timestamp); return(TOK_SYSLOG_KERNEL); }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 419 "scanner.l"
{ return(TOK_SYSLOG_USER); }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 420 "scanner.l"
{ yylval->t_str = strdup(yytext); return(TOK_DATE_MONTH); }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 421 "scanner.l"
{ yylval->t_str = strdup(yytext); return(TOK_DATE); }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 422 "scanner.l"
{ yylval->t_str = strndup(yytext, strlen(yytext)-1); return(TOK_DATE); }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 423 "scanner.l"
{ yylval->t_str = strdup(yytext); BEGIN(hostname); return(TOK_TIME); }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 425 "scanner.l"
{ yy_push_state(audit_id, yyscanner); return(TOK_AUDIT); }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 426 "scanner.l"
{ yylval->t_str = strdup(yytext); return(TOK_DMESG_STAMP); }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 428 "scanner.l"
{ /* ignore any non-matched input */ BEGIN(unknown_message); yyless(0); }
	YY_BREAK

case 132:
/* rule 132 can match eol */
YY_RULE_SETUP
#line 431 "scanner.l"
{ /* eat whitespace */ }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 432 "scanner.l"
{ BEGIN(dmesg_timestamp); return(TOK_SOCKLOGD_KERNEL); }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 433 "scanner.l"
{ yylval->t_str = strdup(yytext); BEGIN(INITIAL); return(TOK_ID); }
	YY_BREAK


case 135:
/* rule 135 can match eol */
YY_RULE_SETUP
#line 437 "scanner.l"
{ /* eat whitespace */ }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 438 "scanner.l"
{ yylval->t_str = strdup(yytext); BEGIN(INITIAL); return(TOK_DMESG_STAMP); }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 439 "scanner.l"
{ /* no timestamp in this message */ BEGIN(INITIAL); yyless(0); }
	YY_BREAK


case 138:
/* rule 138 can match eol */
YY_RULE_SETUP
#line 443 "scanner.l"
{ /* eat whitespace */ }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 444 "scanner.l"
{ yy_push_state(audit_id, yyscanner); return(TOK_AUDIT); }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 445 "scanner.l"
{ return(TOK_KEY_MSG); }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 446 "scanner.l"
{ return(TOK_EQUALS); }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 447 "scanner.l"
{ return(TOK_COLON); }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 448 "scanner.l"
{ BEGIN(unknown_message); yyless(0); /* dump the rest */ }
	YY_BREAK


case 144:
YY_RULE_SETUP
#line 452 "scanner.l"
{ yylval->t_str = strdup(yytext); return(TOK_MSG_REST); }
	YY_BREAK
case 145:
/* rule 145 can match eol */
YY_RULE_SETUP
#line 453 "scanner.l"
{ /* not sure why needed here and not elsewhere */ }
	YY_BREAK

case 146:
YY_RULE_SETUP
#line 457 "scanner.l"
ECHO;
	YY_BREAK
#line 2583 "scanner.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(single_quoted_string):
			case YY_STATE_EOF(quoted_string):
			case YY_STATE_EOF(sub_id):
			case YY_STATE_EOF(audit_id):
			case YY_STATE_EOF(hostname):
			case YY_STATE_EOF(dmesg_timestamp):
			case YY_STATE_EOF(safe_string):
			case YY_STATE_EOF(audit_types):
			case YY_STATE_EOF(ip_addr):
			case YY_STATE_EOF(other_audit):
			case YY_STATE_EOF(unknown_message):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	yyg->yy_state_ptr = yyg->yy_state_buf;
	*yyg->yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 706 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*yyg->yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */

	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 706 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 705);
	if ( ! yy_is_jam )
		*yyg->yy_state_ptr++ = yy_current_state;

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  _new_state , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( yyg->yy_start_stack_ptr >= yyg->yy_start_stack_depth )
		{
		yy_size_t new_size;

		yyg->yy_start_stack_depth += YY_START_STACK_INCR;
		new_size = (yy_size_t) yyg->yy_start_stack_depth * sizeof( int );

		if ( ! yyg->yy_start_stack )
			yyg->yy_start_stack = (int *) yyalloc( new_size , yyscanner );

		else
			yyg->yy_start_stack = (int *) yyrealloc(
					(void *) yyg->yy_start_stack, new_size , yyscanner );

		if ( ! yyg->yy_start_stack )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	yyg->yy_start_stack[yyg->yy_start_stack_ptr++] = YY_START;

	BEGIN(_new_state);
}

    static void yy_pop_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( --yyg->yy_start_stack_ptr < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN(yyg->yy_start_stack[yyg->yy_start_stack_ptr]);
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

    yyg->yy_state_buf = 0;
    yyg->yy_state_ptr = 0;
    yyg->yy_full_match = 0;
    yyg->yy_lp = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    yyfree ( yyg->yy_state_buf , yyscanner);
    yyg->yy_state_buf  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 457 "scanner.l"


